==> open-xchange-publish_7.2.1.orig.tar.bz2: open-xchange-publish-7.2.1/com.openexchange.publish.microformats/src/com/openexchange/publish/microformats/MicroformatStrings.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.microformats;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link MicroformatStrings}
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public final class MicroformatStrings implements LocalizableStrings {

    public static final String DISCLAIMER_PRIVACY = "Privacy:\n"
    +   "The data and any references contained in this webpage are shared with you under the assumption "
    +   "that the owner of the data was entitled to make them available to you. Neither Open-Xchange, "
    +   "nor any of its subsidiaries or affiliates shall be liable for its publication or "
    +   "re-publication.\n"
    +   "Any unauthorized use or dissemination of this data is prohibited. If you intend to store, "
    +   "process, or pass on this data, please make sure that you have the right to do so.\n"
    +   "If you are one of the people listed or responsible for a resource listed on this page and you "
    +   "don't agree with the publication, please send an email containing the URL (the link) to this "
    +   "webpage to %s and the publisher of the data:\n"
    +   "Data published by %s on %s\n";

    public MicroformatStrings() {
        super();
    }
}

==> open-xchange-publish_7.4.2.orig.tar.bz2: open-xchange-publish-7.4.2/com.openexchange.publish.microformats/src/com/openexchange/publish/microformats/MicroformatStrings.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.microformats;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link MicroformatStrings}
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public final class MicroformatStrings implements LocalizableStrings {

    public static final String DISCLAIMER_PRIVACY = "Privacy:\n"
        +   "The data and any references contained in this webpage are shared with you under the assumption "
        +   "that the owner of the data was entitled to make them available to you. Neither %s, "
        +   "nor any of its subsidiaries or affiliates shall be liable for its publication or "
        +   "re-publication.\n"
        +   "Any unauthorized use or dissemination of this data is prohibited. If you intend to store, "
        +   "process, or pass on this data, please make sure that you have the right to do so.\n"
        +   "If you are one of the people listed or responsible for a resource listed on this page and you "
        +   "don't agree with the publication, please send an email containing the URL (the link) to this "
        +   "webpage to %s and the publisher of the data:\n"
        +   "Data published by %s on %s\n";

    public static final String DISCLAIMER_ALTERNATIV_HOSTER_NAME_WORDING = "the hoster";

    public MicroformatStrings() {
        super();
    }
}
